@@ -16,7 +16,7 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
+Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 #include "driver.h"
 
@@ -64,7 +64,8 @@ void printer::load_font(int n, const char *nm)
       if (n >= nfonts)
 	nfonts = n + 1;
       font_table = new font *[nfonts];
-      for (int i = 0; i < old_nfonts; i++)
+      int i;
+      for (i = 0; i < old_nfonts; i++)
 	font_table[i] = old_font_table[i];
       for (i = old_nfonts; i < nfonts; i++)
 	font_table[i] = 0;
