@@ -16,7 +16,7 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
+Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 #include <stdio.h>
 #include <string.h>
@@ -99,3 +99,4 @@ extern int command_char;
 extern int zero_length_line_flag;
 extern int driver_extension_flag;
 extern int compatible_flag;
+extern int safer_flag;
